import java.util.*;

class Patient {
    int id;
    int priority;
    int doctor;

    Patient(int id, int priority, int doctor) {
        this.id = id;
        this.priority = priority;
        this.doctor = doctor;
    }
}

class Hospital {
    private final PriorityQueue<Patient>[] queues;
    private int patientId = 1;

    public Hospital(int numDoctors) {
        queues = new PriorityQueue[numDoctors];
        for (int i = 0; i < numDoctors; i++) {
            queues[i] = new PriorityQueue<>((p1, p2) -> {
                if (p1.priority != p2.priority) {
                    return Integer.compare(p2.priority, p1.priority); // Descending order by priority
                } else {
                    return Integer.compare(p1.id, p2.id); // Ascending order by id (earliest arrival)
                }
            });
        }
    }

    public void enqueue(int doctor, int priority) {
        queues[doctor - 1].add(new Patient(patientId++, priority, doctor));
    }

    public int dequeue(int doctor) {
        if (queues[doctor - 1].isEmpty()) {
            return -1; // No patient to treat
        }
        return Objects.requireNonNull(queues[doctor - 1].poll()).id;
    }
}

public class 看病要排队 {
    public static void main(String[] args) {
        Scanner scanner = new Scanner(System.in);
        int n, doctor, priority;
        Hospital hospital = new Hospital(3); // 3 doctors

        while (scanner.hasNext()) {
            n = scanner.nextInt();
            for (int i = 0; i < n; i++) {
                String event = scanner.next();
                if (event.equals("IN")) {
                    doctor = scanner.nextInt();
                    priority = scanner.nextInt();
                    hospital.enqueue(doctor, priority);
                }
                else if (event.equals("OUT")){
                    doctor = scanner.nextInt();
                    int treatedPatientId = hospital.dequeue(doctor);
                    if (treatedPatientId == -1) {
                        System.out.println("EMPTY");
                    }
                    else {
                        System.out.println(treatedPatientId);
                    }
                }
            }
        }
        scanner.close();
    }
}